@@ -10,7 +10,7 @@ module Slack
 
         def call payload={}
           return payload unless payload[:text]
-          payload[:text] = Util::LinkFormatter.format(payload[:text], options)
+          payload[:text] = Util::LinkFormatter.format(payload[:text], **options)
 
           payload
         end
